@@ -33,6 +33,7 @@
 #' @param cut.landmark cut-off for landmark analysis, Default = NULL
 #' @param showpercent Shows the percentages on the right side.
 #' @param status.cmprsk Status value when competing risk analysis, Default = 2nd level of status variable
+#' @param linewidth Line witdh, Default = 0.75
 #' @param ... PARAM_DESCRIPTION
 #' @return Plot
 #' @details DETAILS
@@ -109,6 +110,7 @@ jskm <- function(sfit,
                  cut.landmark = NULL,
                  showpercent = F,
                  status.cmprsk = NULL,
+                 linewidth = 0.75,
                  ...) {
   
   
@@ -250,7 +252,7 @@ jskm <- function(sfit,
       }
       
       df11 <- rbind(subset(df, time < cut.landmark), df2[, names(df)]) 
-      df <- rbind(df11, data.frame(time = cut.landmark, n.risk = summary(sfit, times = cut.landmark)$n.risk[[1]],  n.event = 0, n.censor = 0, surv = 1, strata = factor(ystratalabs, levels = levels(df$strata)), upper = 1, lower = 1))
+      df <- rbind(df11, data.frame(time = cut.landmark, n.risk = summary(sfit, times = cut.landmark)$n.risk[[1]],  n.event = 0, n.censor = 0, surv = 1, strata = levels(df$strata), upper = 1, lower = 1))
     } else{
       if (is.null(status.cmprsk)){
         status.cmprsk <- sfit$states[2]
@@ -268,7 +270,7 @@ jskm <- function(sfit,
                      by = c("time", "strata"))
       }
       df11 <- rbind(subset(df, time < cut.landmark), df2[, names(df)]) 
-      df <- rbind(df11, data.frame(time = cut.landmark, n.risk = summary(sfit, times = cut.landmark)$n.risk[[1]],  n.event = 0, n.censor = 0, surv = 0, strata = factor(ystratalabs, levels = levels(df$strata)), upper = 0, lower = 0))
+      df <- rbind(df11, data.frame(time = cut.landmark, n.risk = summary(sfit, times = cut.landmark)$n.risk[[1]],  n.event = 0, n.censor = 0, surv = 0, strata = levels(df$strata), upper = 0, lower = 0))
     }  
     
     
@@ -347,12 +349,13 @@ jskm <- function(sfit,
   
   #Add lines too plot
   if (is.null(cut.landmark)){
-    p <- p + geom_step(linewidth = 0.75) +
+    p <- p + geom_step(linewidth = linewidth) +
       scale_linetype_manual(name = ystrataname, values=linetype) +
       scale_colour_brewer(name = ystrataname, palette=linecols)
   } else{
-    p <- p + geom_step(data = subset(df, time < cut.landmark), linewidth = 0.75) + geom_step(data = subset(df, time >= cut.landmark), linewidth = 0.75) + 
-      scale_linetype_manual(name = ystrataname, values=linetype) +
+    p <- p +
+      scale_linetype_manual(name = ystrataname, values=linetype) +  
+      geom_step(data = subset(df, time >= cut.landmark), linewidth = linewidth) + geom_step(data = subset(df, time < cut.landmark), linewidth = linewidth) + 
       scale_colour_brewer(name = ystrataname, palette=linecols)
   }
   
